#!/bin/ksh
#
#  IBM
#  Net.Commerce
#
#  Copyright IBM Corp., 1999.
#
#  Net.Commerce Version 3.2.1 Database Migration Utility
#
#   Dependencies
#   This utility should be running from the DB2 command line
#   against a V3.2 database
#


# ***************************************************************
# ***************************************************************
# Check syntax
# ***************************************************************
# ***************************************************************
if [ $# -lt 1 ]; then
 echo "Usage: chs321migrate.sh Dbname [Logfile] [Username] [Password]" 
 echo "        		       Dbname   : the name of the database to be connected"
 echo "        		       Logfile  : the full path and name of the Logfile"
 echo "                  	          (default is [Dbname].log in current dir)"   
 echo "        		       Username : the name of the user who connect to the database"
 echo "        		       Password : the password of the user" 
 exit 1
fi

if [ -z "${NCPATH}" ]; then
  export NCPATH="/usr/lpp/NetCommerce3"
fi
export NCSCHEMA="$NCPATH/nc_schema/db2"

export dbuser=""
export dbpswd=""
export ncuser=""
if [ $# -eq 4 ]; then
 export dbuser="$3"
 export dbpswd="$4"
 export ncuser="user $dbuser using $dbpswd"
fi

export outlog="$1.log"
if [ $# -gt 1 ]; then
 export outlog="$2"
fi


# ***************************************************************
# ***************************************************************
# Verify if the Net.Commerce Base Database is Version 3.2
# ***************************************************************
# ***************************************************************

echo
db2 activate database $1 $ncuser
db2 connect to $1 $ncuser

$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/dbver.chs32.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "The current level of your Net.Commerce Database Schema is not 3.2 Base and not CHS"
 db2 deactivate database $1 $ncuser
 exit 2
fi


# ******************************************************************
# Set version to an intermediate state in mall Table
# ******************************************************************
#$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/mall.chs321.db2.sql $outlog $dbuser $dbpswd
#if [ $? -ne 0 ]; then
# echo "Error running mall.chs321.db2.sql"
# db2 deactivate database $1 $ncuser
# exit 3
#fi

# ***************************************************************
# ***************************************************************
# Migrate tables in the Net.Commerce Base Database to CHS V3.1.2.2
# ***************************************************************
# ***************************************************************
echo
echo
echo Migrating tables in database $1 
#The following scripts may contain duplicate insertions so errors will be ignored
	
$NCSCHEMA/db_script3.sh $1 $NCSCHEMA/migrate/curformat.v3122.db2.sql $outlog $dbuser $dbpswd
echo Please ignore the error from curformat.v3122.db2.sql
echo Please ignore the error from curformat.v3122.db2.sql 2>&1 >> $outlog

$NCSCHEMA/db_script3.sh $1 $NCPATH/nc_schema/common/migrate/alterstats.v3122.sql $outlog $dbuser $dbpswd
echo Please ignore the error from alterstats.v3122.sql 2>&1 >> $outlog
echo Please ignore the error from alterstats.v3122.sql

#temporarily remove this
$NCSCHEMA/db_script6.sh $1 $NCPATH/nc_schema/common/migrate/addrbookchs_ofs.v3122.sql $outlog $dbuser $dbpswd
echo Please ignore the error from addrbookchs_of.v3122.sql
echo Please ignore the error from addrbookchs_of.v3122.sql 2>&1 >> $outlog

$NCSCHEMA/db_script6.sh $1 $NCPATH/nc_schema/common/migrate/statcode.v3122.sql $outlog $dbuser $dbpswd
echo Please ignore the error from statcode.v3122.sql
echo Please ignore the error from statcode.v3122.sql 2>&1 >> $outlog

$NCSCHEMA/db_script6.sh $1 $NCPATH/nc_schema/common/migrate/acc_ctrl_pay_cmds.v3122.sql $outlog $dbuser $dbpswd
echo Please ignore the error from acc_ctrl_pay_cmds.v3122.sql
echo Please ignore the error from acc_ctrl_pay_cmds.v3122.sql 2>&1 >> $outlog

$NCSCHEMA/db_script6.sh $1 $NCSCHEMA/migrate/reports.v3122.db2.sql $outlog $dbuser $dbpswd
echo Please ignore the error from reports.v3122.db2.sql
echo Please ignore the error from reports.v3122.db2.sql 2>&1 >> $outlog



# ***************************************************************
# ***************************************************************
# Migrate tables in the Net.Commerce Base Database to CHS V3.2.1
# ***************************************************************
# ***************************************************************
echo
echo
echo Migrating tables in database $1

$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/db2/levofser_schema.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
  echo "Error running levofser_schema.db2.sql"
  exit 6
fi

#ignore error
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/melevel.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
  echo "Please ignore the no row found error in melevel.v321.sql" 2>&1 >> $outlog
fi

# works
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/setprofile.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running setprofile.v321.sql"
 db2 deactivate database $1 $ncuser
 exit 6
fi

# works
$NCSCHEMA/db_script6.sh $1 $NCSCHEMA/migrate/mcsplock_schema.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Please ignore error running mcsplock_schema.db2.sql" 2>&1 >> $outlog
fi


# something wrong with this ones
# works once I change '#' comments to 'echo'
# probably obsolete since the new timestamp method is being used to
#	  register these automatically
#$NCSCHEMA/db_script.sh $1 #$NCPATH/nc_schema/common/migrate/acc_ctrl.v321.sql $outlog $dbuser #$dbpswd
#if [ $? -ne 0 ]; then
# echo "Error running acc_ctrl.v321.sql"
# db2 deactivate database $1 $ncuser
# exit 10
#fi

# works, must come after acc_ctrl_pay_cmds.v3122.sql
$NCSCHEMA/db_script6.sh $1 $NCPATH/nc_schema/common/migrate/acc_ctrl_pay_cmds.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running acc_ctrl_pay_cmds.v321.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi

# works
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/taxtype.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running taxtype.v321.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi


$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/inventory_cmds.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running inventory_cmds.v321.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi

$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/db2/migrate/taxship_orcomment.v321.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running taxship_orcomment.v321.db2.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi

$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/db2/migrate/shipcolumns.v321.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Please ignore error running shipcolumns.v321.db2.sql" 2>&1 >> $outlog
fi

$NCSCHEMA/db_script6.sh $1 $NCPATH/nc_schema/db2/migrate/taxship_cmds_delete.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then

 echo "Please ignore error running taxship_cmds_delete.db2.sql" 2>&1 >> $outlog
fi


echo
echo
echo Adding new Functions in database $1
$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/function.v321.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running function.v321.db2.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi

# works but then crashes at the end for no apparent reason, so put it at the end
#ignore error
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/features.v321.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running features.v321.db2.sql" 2>&1 >> $outlog
 echo "Please ignore error running features.v321.db2.sql" 2>&1 >> $outlog
fi

#Fix all dll file insertions to be .a files for aix
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/update_chs_cmds.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running update_chs_cmds.sql" 2>&1 >> $outlog
 echo "Please ignore error running update_chs_cmds.sql" 2>&1 >> $outlog
fi
$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/update_chs_cmds2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running update_chs_cmds2.sql" 2>&1 >> $outlog
 echo "Please ignore error running update_chs_cmds2.sql" 2>&1 >> $outlog
fi

$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/update_server_cmds.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running update_server_cmds.sql" 2>&1 >> $outlog
 echo "Please ignore error running update_server_cmds.sql" 2>&1 >> $outlog
fi

$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/new_indexes.v321.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running new_indexes.v321.sql"
 db2 deactivate database $1 $ncuser
 exit 10
fi


# ***************************************************************
# ***************************************************************
# Update the KEYS table after everything has been done
# ***************************************************************
# ***************************************************************
$NCSCHEMA/db_script6.sh $1 $NCSCHEMA/update_keys.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Please ignore error from update_keys.sql" 2>&1 >> $outlog
fi


# ******************************************************************
# set flag to indicate CHS and set release version in mall Table
# This sql file should be called at the end of migration
# ******************************************************************
$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/setmall.chs321.db2.sql $outlog $dbuser $dbpswd

if [ $? -ne 0 ]; then
 echo "Error running setmall.chs321.db2.sql"
 echo "Please ignore error from setmall.chs321.db2.sql"
# db2 deactivate database $1 $ncuser
# exit 100
fi

echo
echo "NCHS 321 migration complete";
db2 deactivate database $1 $ncuser

echo END: ---- Check the log files ----
