#!/bin/ksh
#
#  IBM
#  Net.Commerce
#
#  Copyright IBM Corp., 1999.
#
#  Net.Commerce Version 3.2 Base Database Migration Utility
#
#   Dependencies
#   This utility should be running from the DB2 command line
#   against a V3.1/V3.1.1/V3.1.2/V3.1.2.2 database
#



# ***************************************************************
# ***************************************************************
# Check syntax
# ***************************************************************
# ***************************************************************
if [ $# -lt 4 ]; then
 echo "Usage: v321migrate.sh Dbname Logfile Username Password [nodename]" 
 echo "        		       Dbname   : the name of the database to be connected"
 echo "        		       Logfile  : the full path and name of the Logfile"
 echo "        		       Username : the name of the user who connect to the database"
 echo "        		       Password : the password of the user" 
 echo "                     Nodename : the name of the remote database node " 
 exit 1
fi


if [ -z "${NCPATH}" ]; then
  export NCPATH="/usr/lpp/NetCommerce3"
fi
export NCSCHEMA="$NCPATH/nc_schema/db2"

if [ $# -ge 4 ]; then
 export root_dbuser="$3"
 export dbpswd="$4"
 export ncuser="user $root_dbuser using $dbpswd"
fi


if [ $# -eq 5 ]; then
 export nodename="$5"
else
 export nodename="$DB2INSTANCE"
fi
export outlog="$1.log"
if [ $# -gt 1 ]; then
 export outlog="$2"
fi


# ***************************************************************
# ***************************************************************
# Migrate from V3.x to V3.2
# ***************************************************************
# ***************************************************************
$NCSCHEMA/migrate/v32migrate.sh $1 $root_dbuser $dbpswd $outlog
if [ $? -ne 0 ]; then
 echo "Error running v32migrate.sh"
 exit 6
fi

# ***************************************************************
# ***************************************************************
# One Time migration steps
# ***************************************************************
# ***************************************************************

# Database configuration change
$NCSCHEMA/migrate/config_migrate.v321.db2.sh $1 $root_dbuser $dbpswd $outlog $nodename 
if [ $? -ne 0 ]; then
 echo "Error running config_migrate.v321.db2.sh"
 exit 6
fi

echo
db2 activate database $1 $ncuser
db2 connect to $1 $ncuser


# These changes are additions that were made to chsdata instead of chs321migrate and were not moved
$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/misc_chsdata_fixes.v32.db2.sql $outlog $root_dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running misc_chsdata_fixes.v32.db2.sh"
 exit 8 
fi 

$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/misc_chsdata_fixes2.v32.db2.sql $outlog $root_dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Please ignore error running misc_chsdata_fixes2.v32.db2.sh"
fi 


# ***************************************************************
# ***************************************************************
# Migrate from V3.2 to V3.2.1
# ***************************************************************
# ***************************************************************
$NCSCHEMA/migrate/chs321migrate.sh $1 $outlog $root_dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running chs321migrate.sh"
 exit 6
fi

echo
db2 deactivate database $1 $ncuser
echo "Database migration complete" >> $outlog
echo END: ---- Check the log files ----
