#!/bin/ksh
#
#  IBM
#  Net.Commerce
#
#  Copyright IBM Corp., 1999.
#
#  Net.Commerce Version 3.2 Base Database Migration Utility
#
#   Dependencies
#   This utility should be running from the DB2 command line
#   against a V3.1.2.2 database
#


# ***************************************************************
# ***************************************************************
# Check syntax
# ***************************************************************
# ***************************************************************
if [ $# -lt 1 ]; then
 echo "Usage: nc32migrate.sh Dbname [Logfile] [Username] [Password]" 
 echo "        		       Dbname   : the name of the database to be connected"
 echo "        		       Logfile  : the full path and name of the Logfile"
 echo "                  	          (default is [Dbname].log in current dir)"   
 echo "        		       Username : the name of the user who connect to the database"
 echo "        		       Password : the password of the user" 
 exit 1
fi

if [ -z "${NCPATH}" ]; then
  export NCPATH="/opt/IBMnetc/NetCommerce3"
fi
export NCSCHEMA="$NCPATH/nc_schema/db2"

export dbuser=""
export dbpswd=""
export ncuser=""
if [ $# -eq 4 ]; then
 export dbuser="$3"
 export dbpswd="$4"
 export ncuser="user $dbuser using $dbpswd"
fi

export outlog="$1.log"
if [ $# -gt 1 ]; then
 export outlog="$2"
fi


# ***************************************************************
# ***************************************************************
# Verify if the Net.Commerce Database is Version 3.1.2.2
# ***************************************************************
# ***************************************************************

echo
db2 activate database $1 $ncuser
db2 connect to $1 $ncuser

$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/dbver.v32.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "The current level of your Net.Commerce Database Schema is not 3.1.2.2"
 db2 deactivate database $1 $ncuser
 exit 2
fi


# ***************************************************************
# ***************************************************************
# Set version to an intermediate state in mall Table
# ***************************************************************
# ***************************************************************
$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/mall.v32.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running mall.v32.db2.sql"
 db2 deactivate database $1 $ncuser
 exit 3
fi

# ***************************************************************
# ***************************************************************
# Migrate to Net.Commerce Database V3.2
# ***************************************************************
# ***************************************************************
echo
echo
echo Migrating tables in database $1 


$NCSCHEMA/db_script3.sh $1 $NCSCHEMA/migrate/altertable.v32.db2.sql $outlog $dbuser $dbpswd
echo Please ignore the error from altertable.v32.db2.sql
echo Please ignore the error from altertable.v32.db2.sql 2>&1 >> $outlog


$NCSCHEMA/db_script3.sh $1 $NCPATH/nc_schema/common/view.v32.sql $outlog $dbuser $dbpswd
echo Please ignore the error from view.v32.sql
echo Please ignore the error from view.v32.sql 2>&1 >> $outlog


$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/cmds_ofs.v32.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running cmds_ofs.v32.sql"
 echo Please ignore the error from cmds_ofs.v32.sql 
 # db2 deactivate database $1 $ncuser
 # exit 14
fi


$NCSCHEMA/db_script3.sh $1 $NCPATH/nc_schema/db2/migrate/icat_schema.v32.db2.sql $outlog $dbuser $dbpswd
echo Please ignore the warning from icat_schema.v32.db2.sql
echo Please ignore the warning from icat_schema.v32.db2.sql 2>&1 >> $outlog


$NCSCHEMA/db_script.sh $1 $NCPATH/nc_schema/common/migrate/icat.v32.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running icat.v32.sql"
 db2 deactivate database $1 $ncuser
 exit 18
fi



# ***************************************************************
# ***************************************************************
# At the end of setmall, set version in mall Table
# This sql file should be called at the end
# ***************************************************************
# ***************************************************************
$NCSCHEMA/db_script.sh $1 $NCSCHEMA/migrate/setmall.v32.db2.sql $outlog $dbuser $dbpswd
if [ $? -ne 0 ]; then
 echo "Error running setmall.v32.db2.sql"
 db2 deactivate database $1 $ncuser
 exit 42
fi

echo
db2 deactivate database $1 $ncuser

echo END: ---- Check the log files ----
